pub struct KeyedRateLimiter { /* private fields */ }Expand description
Per-key rate limiter using in-memory tracking Maintains separate rate limits for each key (IP, user ID, etc.)
Implementations
Sourceimpl KeyedRateLimiter
impl KeyedRateLimiter
Sourcepub fn new(config: RateLimitConfig) -> Self
pub fn new(config: RateLimitConfig) -> Self
Create a new keyed rate limiter
Sourcepub fn check(&self, key: &str) -> Result<()>
pub fn check(&self, key: &str) -> Result<()>
Check if a request should be allowed for the given key
Returns Ok(()) if allowed, Err with status code if rate limited
Sourcepub fn active_limiters(&self) -> usize
pub fn active_limiters(&self) -> usize
Get the number of active rate limiters (for monitoring)
Sourcepub fn clone_config(&self) -> RateLimitConfig
pub fn clone_config(&self) -> RateLimitConfig
Create a copy for independent testing