pub struct DatabaseConfigBuilder { /* private fields */ }Expand description
Builder for DatabaseConfig.
Implementations
Sourceimpl DatabaseConfigBuilder
impl DatabaseConfigBuilder
Sourcepub fn url_env(self, url_env: impl Into<String>) -> Self
pub fn url_env(self, url_env: impl Into<String>) -> Self
Sets the environment variable name that holds the database URL.
Sourcepub const fn pool_size(self, pool_size: u32) -> Self
pub const fn pool_size(self, pool_size: u32) -> Self
Sets the maximum number of connections in the pool.
Sourcepub fn pool_timeout(self, pool_timeout: impl Into<String>) -> Self
pub fn pool_timeout(self, pool_timeout: impl Into<String>) -> Self
Sets how long to wait for a connection before returning an error.
Sourcepub fn statement_timeout(self, statement_timeout: impl Into<String>) -> Self
pub fn statement_timeout(self, statement_timeout: impl Into<String>) -> Self
Sets the per-query statement timeout.
Sourcepub fn replica(self, replica: ReplicaConfig) -> Self
pub fn replica(self, replica: ReplicaConfig) -> Self
Adds a read replica.
Sourcepub fn health_check_interval(
self,
health_check_interval: impl Into<String>,
) -> Self
pub fn health_check_interval( self, health_check_interval: impl Into<String>, ) -> Self
Sets the health-check ping interval.
Sourcepub fn build(self) -> Result<DatabaseConfig, String>
pub fn build(self) -> Result<DatabaseConfig, String>