pub struct BearerAuthState {
pub token: Arc<String>,
/* private fields */
}Expand description
Shared state for bearer token authentication.
Fields
token: Arc<String>Expected bearer token.
Implementations
Sourceimpl BearerAuthState
impl BearerAuthState
Sourcepub fn new(token: String) -> Self
pub fn new(token: String) -> Self
Create new bearer auth state with the default max-failures limit (10).
Sourcepub fn with_max_failures(token: String, max_failures: u32) -> Self
pub fn with_max_failures(token: String, max_failures: u32) -> Self
Create new bearer auth state with a custom max-failures limit.
After max_failures failed attempts from the same IP within a 60-second
window, further requests receive 429 Too Many Requests.