pub struct RealtimeServer { /* private fields */ }Expand description
The realtime WebSocket server.
Implementations
Sourceimpl RealtimeServer
impl RealtimeServer
Sourcepub fn new(config: RealtimeConfig) -> Self
pub fn new(config: RealtimeConfig) -> Self
Create a new realtime server with the given configuration.
Sourcepub fn with_entities(config: RealtimeConfig, entities: HashSet<String>) -> Self
pub fn with_entities(config: RealtimeConfig, entities: HashSet<String>) -> Self
Create a new realtime server with known entities for subscription validation.
Sourcepub fn active_connections(&self) -> usize
pub fn active_connections(&self) -> usize
Returns the number of active connections.