pub struct ExtendedCompiledSchema {
pub schema: CompiledSchema,
pub storage: Option<SchemaStorageConfig>,
pub functions: Option<FunctionsConfig>,
pub realtime: Option<RealtimeSchemaConfig>,
}Expand description
A compiled schema with all optional platform extensions parsed out.
Use CompiledSchemaLoader::load_extended to obtain this type. It bundles the
core CompiledSchema together with optional storage, functions, and realtime
configurations that are embedded in the compiled schema JSON.
Fields
schema: CompiledSchemaCore compiled GraphQL schema (types, queries, mutations, subscriptions).
storage: Option<SchemaStorageConfig>Storage bucket configuration, if the "storage" key is present and non-null.
functions: Option<FunctionsConfig>Serverless functions configuration, if the "functions" key is present.
realtime: Option<RealtimeSchemaConfig>Realtime broadcast observer configuration, if the "realtime" key is present.